Learn R Programming

mdw (version 2024.8-1)

asym.v.v: Asymptotic variance for maximum variance weights

Description

asym.v.v produces estimated asymptotic covariance matrix of the first p-1 maximum variance weights (because the p weights sum to 1).

Usage

asym.v.v(X, w)

Arguments

X

n by p maxtrix containing observations of p biomarkers of n subjects.

w

maximum variance weights for dateset X

Examples

Run this code
library(MASS)
# a three biomarkers dataset generated from independent normal(0,1)
X = mvrnorm(n = 100, mu=rep(0,3), Sigma=diag(3), tol = 1e-6, empirical = FALSE, EISPACK = FALSE)
w <- var.weight(X)
asym.v.v(X,w)

Run the code above in your browser using DataLab