powered by
tree.weight Produce a set of weights for different end points based on a correlation matrix using the GSC tree method
tree.weight
tree.weight (cor.mat, method="GSC", clustering.method="average", plot=TRUE, orientation=c("vertical","horizontal"), ...)
A vector of weights that sum to 1.
a matrix, correlation matrix
a string. GSC, implementation of Gerstein et al., is the only implemented currently
a string, how the bottom-up hierarchical clustering tree is built, is passed to hclust as the method parameter
a Boolean, whether to plot the tree
vertical or horizontal
additional args
Youyi Fong yfong@fhcrc.org
Gerstein, M., Sonnhammer, E., and Chothia, C. (1994), Volume changes in protein evolution. J Mol Biol, 236, 1067-78.
cor.mat=diag(rep(1,3)) cor.mat[1,2]<-cor.mat[2,1]<-0.9 cor.mat[1,3]<-cor.mat[3,1]<-0.1 cor.mat[2,3]<-cor.mat[3,2]<-0.1 tree.weight(cor.mat)
Run the code above in your browser using DataLab